@@ -29,12 +29,14 @@
 #include <config.h>
 #include <gtk/gtk.h>
 #include <gtk/gtkcombobox.h>
+#include <gst/player/player.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include "gnome-internet-radio-locator.h"
 #include "gnome-internet-radio-locator-gui.h"
 #include "gnome-internet-radio-locator-keys.h"
+#include "gnome-internet-radio-locator-player.h"
 #include "gnome-internet-radio-locator-program.h"
 #include "gnome-internet-radio-locator-station.h"
 #include "gnome-internet-radio-locator-streams.h"
@@ -43,25 +45,21 @@
 extern GtkWidget *gnome_internet_radio_locator_app;
 extern GtkWidget *search_selector;
 extern GtkWidget *input;
+extern GtkWidget *statusbar;
+extern GstPlayer *player;
 
 GNOMEInternetRadioLocatorStationInfo *stationinfo, *localstation;
 
 GtkWidget *create_stations_selector(char *selected_station_uri,
 				    char *filename)
 {
-
 	GtkWidget *stations_selector;
 	GtkWidget *align, *menu, *drop_down, *item;
-
 	gchar *station_uri, *station_name, *station_location, *station_band, *station_description, *station_website;
 	gchar *label, *world_station_xml_filename, *local_station_xml_file;
-
 	int i = 0, selection = -1;
-
 	GStatBuf stats;
-
 	memset(&stats, 0, sizeof(stats));
-
 	/* The Stations dialog */
 	/* stations_selector = gtk_dialog_new_with_buttons("Select a station", */
 	/* 						GTK_WINDOW(gnome_internet_radio_locator_app), */
@@ -77,12 +75,9 @@ GtkWidget *create_stations_selector(char *selected_station_uri,
 	/* 		  (GTK_DIALOG(stations_selector)->vbox), align); */
 	/* gtk_container_set_border_width(GTK_CONTAINER(align), 6); */
 	/* gtk_widget_show(align); */
-
 	menu = gtk_menu_new();
 	gtk_widget_show(menu);
-
 	/* creating the menu items */
-
 	/* world_station_xml_filename = gnome_program_locate_file(NULL, */
 	/* 						       GNOME_FILE_DOMAIN_APP_DATADIR, */
 	/* 						       "gnome-internet-radio-locator/gnome-internet-radio-locator.xml", */
@@ -90,16 +85,13 @@ GtkWidget *create_stations_selector(char *selected_station_uri,
 	/* 						       NULL); */
 
 	/* world_station_xml_filename = g_strdup("https://people.gnome.org/~ole/gnome-internet-radio-locator/gnome-internet-radio-locator.xml"); */
-
 	world_station_xml_filename = g_strconcat(GNOME_INTERNET_RADIO_LOCATOR_DATADIR, "/gnome-internet-radio-locator.xml", NULL);
 	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("world_station_xml_filename = %s\n",
 	    world_station_xml_filename);
-
 	if (world_station_xml_filename == NULL) {
 		g_warning(_("Failed to open %s\n"),
 			  world_station_xml_filename);
 	}
-
 	local_station_xml_file =
 	    g_strconcat(g_get_home_dir(), "/.gnome-internet-radio-locator/gnome-internet-radio-locator.xml", NULL);
 
@@ -108,19 +100,14 @@ GtkWidget *create_stations_selector(char *selected_station_uri,
 	} else {
 		localstation = NULL;
 	}
-
 	if (localstation == NULL) {
 		g_warning(_("Failed to open %s\n"), local_station_xml_file);
 	}
-
 /*   g_free (local_station_xml_file); */
-
 	stationinfo =
 	    gnome_internet_radio_locator_station_load_from_file(localstation,
 					world_station_xml_filename);
-
 	gnome_internet_radio_locator_stations = NULL;
-
 	while (stationinfo != NULL) {
 
 		label =
@@ -219,15 +206,20 @@ void
 save_cb (GtkWidget *widget, gpointer data) {
 
 	/* g_print("%s\n", data); */
-
-	char *nameentry, *locationentry, *urientry, *websiteentry, *descriptionentry;
-
+        gint context_id;
+        char *nameentry, *locationentry, *urientry, *websiteentry, *descriptionentry, *statusmsg;
 	nameentry = g_object_get_data(G_OBJECT(widget), "station_name");
 	locationentry = g_object_get_data(G_OBJECT(widget), "station_location");
 	urientry = g_object_get_data(G_OBJECT(widget), "station_uri");
 	websiteentry = g_object_get_data(G_OBJECT(widget), "station_website");
 	descriptionentry = g_object_get_data(G_OBJECT(widget), "station_description");
-
+	player = gst_player_new (NULL, gst_player_g_main_context_signal_dispatcher_new(NULL));
+	gnome_internet_radio_locator_player_new(GST_PLAYER(player), urientry);
+	context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (statusbar), "Station Name");
+	statusmsg = g_strconcat("Added ", nameentry, " in ", locationentry, NULL);
+	gtk_statusbar_push (GTK_STATUSBAR (statusbar), GPOINTER_TO_INT (context_id), statusmsg);
+	gst_player_stop(player);
+	gst_player_play(player);
 	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("%s\n", nameentry);
 	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("%s\n", locationentry);
 	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("%s\n", urientry);
@@ -269,7 +261,7 @@ GtkWidget *create_new_station_selector(gchar *location) {
 						       NULL);
 	content_area = gtk_dialog_get_content_area (GTK_DIALOG (station_selector));
 
-	g_signal_connect(G_OBJECT(station_selector), "response", G_CALLBACK(save_cb), NULL);
+	g_signal_connect(G_OBJECT(station_selector), "response", G_CALLBACK(save_cb), G_OBJECT(station_selector));
 	/* gtk_container_set_border_width */
 	/* 	(GTK_CONTAINER(GTK_DIALOG(station_selector)->vbox), 6);  */
 
@@ -302,96 +294,85 @@ GtkWidget *create_new_station_selector(gchar *location) {
 	g_signal_connect(G_OBJECT(completion), "match-selected",
 			 G_CALLBACK(on_location_matches), NULL);
 	location_model = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
-
 	world_station_xml_filename = g_strconcat(GNOME_INTERNET_RADIO_LOCATOR_DATADIR, "/gnome-internet-radio-locator.xml", NULL);
 	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("world_station_xml_filename = %s\n",
 	    world_station_xml_filename);
-
 	if (world_station_xml_filename == NULL) {
 		g_warning((_("Failed to open %s.  Please install it.\n")),
 			  world_station_xml_filename);
 	}
-
 	local_station_xml_file =
 	    g_strconcat(g_get_home_dir(), "/.gnome_internet_radio_locator/gnome_internet_radio_locator.xml", NULL);
-
 	if (!g_stat(local_station_xml_file, &stats)) {
 		localstation = gnome_internet_radio_locator_station_load_from_file(NULL, local_station_xml_file);
 	} else {
 		localstation = NULL;
 	}
-
 	if (localstation == NULL) {
 		g_warning(_("Failed to open %s\n"), local_station_xml_file);
 	}
-
 	stationinfo = gnome_internet_radio_locator_station_load_from_file(localstation,
 									  world_station_xml_filename);
-
-	  gtk_widget_show(nameentry);
-	  gtk_widget_show(locationentry);
-	  gtk_widget_show(urientry);
-	  gtk_widget_show(bandentry);
-	  gtk_widget_show(descriptionentry);
-	  gtk_widget_show(websiteentry);
-	  gtk_container_add(GTK_CONTAINER(content_area), nameentry);
-	  gtk_container_add(GTK_CONTAINER(content_area), bandentry);
-	  gtk_container_add(GTK_CONTAINER(content_area), locationentry);
-	  gtk_container_add(GTK_CONTAINER(content_area), urientry);
-	  gtk_container_add(GTK_CONTAINER(content_area), descriptionentry);
-	  gtk_container_add(GTK_CONTAINER(content_area), websiteentry);
-	  /* g_signal_connect(G_OBJECT(station_selector), GTK_RESPONSE_ACCEPT, */
-	  /* 		 G_CALLBACK(on_new_station_selector_changed), */
-	  /* 		 NULL); */
-	  g_object_set_data(G_OBJECT(station_selector), "station_name",
-			    (gpointer) gtk_entry_get_text(GTK_ENTRY(nameentry)));
-	  g_object_set_data(G_OBJECT(station_selector), "station_band",
-			    (gpointer) gtk_entry_get_text(GTK_ENTRY(bandentry)));
-	  g_object_set_data(G_OBJECT(station_selector), "station_location",
-			    (gpointer) gtk_entry_get_text(GTK_ENTRY(locationentry)));
-	  GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("LOCATIONENTRY: %s\n", (gpointer) gtk_entry_get_text(GTK_ENTRY(locationentry)));
-	  g_object_set_data(G_OBJECT(station_selector), "station_uri",
-			    (gpointer) gtk_entry_get_text(GTK_ENTRY(urientry)));
-	  GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("URIENTRY: %s\n", (gpointer) gtk_entry_get_text(GTK_ENTRY(urientry)));
-	  g_object_set_data(G_OBJECT(station_selector), "station_description",
-			    (gpointer) gtk_entry_get_text(GTK_ENTRY(descriptionentry)));
-	  g_object_set_data(G_OBJECT(station_selector), "station_website",
-			    (gpointer) gtk_entry_get_text(GTK_ENTRY(websiteentry)));
-	  GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("WEBSITEENTRY: %s\n", (gpointer) gtk_entry_get_text(GTK_ENTRY(websiteentry)));
-
+	gtk_container_add(GTK_CONTAINER(content_area), nameentry);
+	gtk_container_add(GTK_CONTAINER(content_area), bandentry);
+	gtk_container_add(GTK_CONTAINER(content_area), locationentry);
+	gtk_container_add(GTK_CONTAINER(content_area), urientry);
+	gtk_container_add(GTK_CONTAINER(content_area), descriptionentry);
+	gtk_container_add(GTK_CONTAINER(content_area), websiteentry);
+	gtk_widget_show(nameentry);
+	gtk_widget_show(bandentry);
+	gtk_widget_show(locationentry);
+	gtk_widget_show(urientry);
+	gtk_widget_show(descriptionentry);
+	gtk_widget_show(websiteentry);
+	/* g_signal_connect(G_OBJECT(station_selector), GTK_RESPONSE_ACCEPT, */
+	/* 		 G_CALLBACK(on_new_station_selector_changed), */
+	/* 		 NULL); */
+	g_object_set_data(G_OBJECT(station_selector), "station_name",
+			  (gchar *) gtk_entry_get_text(GTK_ENTRY(nameentry)));
+	g_object_set_data(G_OBJECT(station_selector), "station_band",
+			  (gchar *) gtk_entry_get_text(GTK_ENTRY(bandentry)));
+	g_object_set_data(G_OBJECT(station_selector), "station_location",
+			  (gchar *) gtk_entry_get_text(GTK_ENTRY(locationentry)));
+	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("LOCATIONENTRY: %s\n", (gchar *) gtk_entry_get_text(GTK_ENTRY(locationentry)));
+	g_object_set_data(G_OBJECT(station_selector), "station_uri",
+			  (gchar *) gtk_entry_get_text(GTK_ENTRY(urientry)));
+	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("URIENTRY: %s\n", (gchar *) gtk_entry_get_text(GTK_ENTRY(urientry)));
+	g_object_set_data(G_OBJECT(station_selector), "station_description",
+			  (gchar *) gtk_entry_get_text(GTK_ENTRY(descriptionentry)));
+	g_object_set_data(G_OBJECT(station_selector), "station_website",
+			  (gchar *) gtk_entry_get_text(GTK_ENTRY(websiteentry)));
+	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("WEBSITEENTRY: %s\n", (gchar *) gtk_entry_get_text(GTK_ENTRY(websiteentry)));
 #if 0 /* FIXME: Add input fields */
-	  g_object_set_data(G_OBJECT(station_selector), "station_description",
-			    (gpointer) station_description);
-	  g_object_set_data(G_OBJECT(station_selector), "station_website",
-			    (gpointer) station_website);
+	g_object_set_data(G_OBJECT(station_selector), "station_description",
+			  (gchar *) station_description);
+	g_object_set_data(G_OBJECT(station_selector), "station_website",
+			  (gchar *) station_website);
 #endif
-	  // gtk_widget_show(station_selector);
-	  // g_free(label);
-	  g_signal_connect(G_OBJECT(station_selector), "response",
-			   G_CALLBACK(gtk_widget_hide),
-			   (gpointer) station_selector);
-	  g_signal_connect(G_OBJECT(station_selector), "delete-event",
-			   G_CALLBACK(gtk_widget_hide),
-			   (gpointer) station_selector);
-	  /* tz_db_free (db); */
-	  /* g_free (pixmap_dir); */
-	  /* g_free (filename); */
-	  /* g_free (path); */
-	  return station_selector;
+	// gtk_widget_show(station_selector);
+	// g_free(label);
+	g_signal_connect(G_OBJECT(station_selector), "response",
+			 G_CALLBACK(gtk_widget_hide),
+			 (gpointer) station_selector);
+	g_signal_connect(G_OBJECT(station_selector), "delete-event",
+			 G_CALLBACK(gtk_widget_hide),
+			 (gpointer) station_selector);
+	/* tz_db_free (db); */
+	/* g_free (pixmap_dir); */
+	/* g_free (filename); */
+	/* g_free (path); */
+	return station_selector;
 }
 
 GtkWidget *create_gnome_internet_radio_locator_app(void)
 {
 	GtkWidget *gnome_internet_radio_locator_app;
 	GtkWidget *vbox1;
-
 	GtkWidget *gnome_internet_radio_locator_pixmap;
-
 	GtkWidget *appbar;
 	GtkWidget *progress;
 	gsize length;
 	const gchar *selected_station, *selected_station_uri, *selected_station_name, *selected_station_location, *selected_station_description;
-	
 	GNOMEInternetRadioLocatorData *gnome_internet_radio_locator_data = g_new0(GNOMEInternetRadioLocatorData, 1);
 	char *pmf;
 	gtk_window_set_title(GTK_WINDOW(gnome_internet_radio_locator_app), "GNOME Internet Radio Locator");
@@ -409,7 +390,6 @@ GtkWidget *create_gnome_internet_radio_locator_app(void)
 	/* gnome_internet_radio_locator->selected_station_description = selected_station_description; */
 #if GNOME_INTERNET_RADIO_LOCATOR_CFG_GNOME_CONFIG
 	gnome_config_push_prefix("/gnome-internet-radio-locator/General/");
-
 	gnome_internet_radio_locator->selected_listener_uri =
 	    gnome_config_get_string("selected_listener_uri=");
 	gnome_internet_radio_locator->selected_listener_name =
@@ -418,7 +398,6 @@ GtkWidget *create_gnome_internet_radio_locator_app(void)
 	    gnome_config_get_string("selected_listener_location=");
 	gnome_internet_radio_locator->selected_listener_description =
 	    gnome_config_get_string("selected_listener_description=");
-
 	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("gnome_internet_radio_locator->selected_listener_uri: %s\n",
 	       gnome_internet_radio_locator->selected_listener_uri);
 	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("gnome_internet_radio_locator->selected_listener_name: %s\n",
@@ -429,7 +408,6 @@ GtkWidget *create_gnome_internet_radio_locator_app(void)
 	       gnome_internet_radio_locator->selected_listener_band);
 	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("gnome_internet_radio_locator->selected_listener_description: %s\n",
 	       gnome_internet_radio_locator->selected_listener_description);
-
 	gnome_internet_radio_locator->selected_station_uri =
 	    gnome_config_get_string("selected_station_uri=");
 	gnome_internet_radio_locator->selected_station_name =
@@ -438,14 +416,12 @@ GtkWidget *create_gnome_internet_radio_locator_app(void)
 	    gnome_config_get_string("selected_station_location=");
 	gnome_internet_radio_locator->selected_station_description =
 	    gnome_config_get_string("selected_station_description=");
-
 	gnome_internet_radio_locator->selected_station_name =
 	    gnome_config_get_string("selected_station_name=");
 	gnome_internet_radio_locator->selected_station_location =
 	    gnome_config_get_string("selected_station_location=");
 	gnome_internet_radio_locator->selected_station_description =
 	    gnome_config_get_string("selected_station_description=");
-
 	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("gnome_internet_radio_locator->selected_station_uri: %s\n",
 	       gnome_internet_radio_locator->selected_station_uri);
 	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("gnome_internet_radio_locator->selected_station_name: %s\n",
@@ -454,7 +430,6 @@ GtkWidget *create_gnome_internet_radio_locator_app(void)
 	       gnome_internet_radio_locator->selected_station_location);
 	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("gnome_internet_radio_locator->selected_station_description: %s\n",
 	       gnome_internet_radio_locator->selected_station_description);
-
 	if (strcmp(gnome_internet_radio_locator->selected_station_uri,"")==0) {
 		gnome_internet_radio_locator->selected_station_uri = g_strdup(_("http://fm939.wnyc.org/wnycfm"));
 	}
@@ -465,12 +440,11 @@ GtkWidget *create_gnome_internet_radio_locator_app(void)
 		gnome_internet_radio_locator->selected_station_location = g_strdup(_("New York City, NY"));
 	}
 	if (strcmp(gnome_internet_radio_locator->selected_station_band,"")==0) {
-		gnome_internet_radio_locator->selected_station_band = g_strdup(_("ONLINE"));
+		gnome_internet_radio_locator->selected_station_band = g_strdup(_("Online"));
 	}
 	if (strcmp(gnome_internet_radio_locator->selected_station_description,"")==0) {
 		gnome_internet_radio_locator->selected_station_description = g_strdup(_("WNYC 93.9 FM and AM 820 are New York's flagship public radio stations, broadcasting the finest programs from NPR, American Public Media, Public Radio International and the BBC World Service, as well as a wide range of award-winning local programming."));
 	}
-
 	gnome_internet_radio_locator->selected_streams_uri =
 		gnome_config_get_string("selected_streams_uri=");
 	gnome_internet_radio_locator->selected_streams_mime =
@@ -483,7 +457,6 @@ GtkWidget *create_gnome_internet_radio_locator_app(void)
 	    gnome_config_get_string("selected_streams_samplerate=");
 	gnome_internet_radio_locator->selected_streams_channels =
 		(Gnome_Internet_Radio_LocatorChannels)gnome_config_get_string("selected_streams_channels=");
-
 	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("gnome_internet_radio_locator->selected_streams_uri: %s\n",
 	       gnome_internet_radio_locator->selected_streams_uri);
 	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("gnome_internet_radio_locator->selected_streams_mime: %s\n",
@@ -496,9 +469,7 @@ GtkWidget *create_gnome_internet_radio_locator_app(void)
 	       gnome_internet_radio_locator->selected_streams_samplerate);
 	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("gnome_internet_radio_locator->selected_channels: %0x\n",
 	       gnome_internet_radio_locator->selected_streams_channels);
-
 	gnome_config_pop_prefix();
 #endif
-
 	return gnome_internet_radio_locator_app;
 }
