@@ -47,6 +47,7 @@ static ChamplainView *champlain_view;
 GApplication *app;
 GtkWidget *search_selector;
 GtkWidget *window;
+GtkWidget *statusbar;
 GNOMEInternetRadioLocatorData *gnome_internet_radio_locator;
 
 GtkWidget *input;
@@ -83,6 +84,24 @@ GStatBuf stats;
 
 ChamplainView *view;
 
+gchar *
+str_channels (GNOMEInternetRadioLocatorChannels type) {
+  gchar *channels;
+  if (type == GNOME_INTERNET_RADIO_LOCATOR_CHANNELS_MONO) {
+    channels = g_strdup("Mono");
+  }
+  if (type == GNOME_INTERNET_RADIO_LOCATOR_CHANNELS_STEREO) {
+    channels = g_strdup("Stereo");
+  }
+  if (type == GNOME_INTERNET_RADIO_LOCATOR_CHANNELS_5_1) {
+    channels = g_strdup("Surround");
+  }
+  if (type == GNOME_INTERNET_RADIO_LOCATOR_CHANNELS_NONE) {
+    channels = g_strdup("None");
+  }
+  return channels;
+}
+
 /*
  * Terminate the main loop.
  */
@@ -121,6 +140,8 @@ mouse_click_cb (ClutterActor *actor, ClutterButtonEvent *event, ChamplainView *v
 	GeocodeLocation *location_city;
 	GeocodeLocation *location_country;
 	GeocodeReverse *reverse_city, *reverse_country;
+	ClutterColor city_color = { 0x9a, 0x9b, 0x9c, 0x9d };
+	ClutterColor text_color = { 0xff, 0xff, 0xff, 0xff };
 
 	const char *name, *name_city, *name_country;
 	/* GeocodeForward *fwd; */
@@ -143,6 +164,8 @@ mouse_click_cb (ClutterActor *actor, ClutterButtonEvent *event, ChamplainView *v
 	marker = champlain_label_new_from_file ("icons/emblem-generic.png", NULL);
 	name = g_strconcat(name_city, ", ", name_country, NULL);
 	champlain_label_set_text (CHAMPLAIN_LABEL (marker), (gchar *)name);
+	champlain_label_set_color (CHAMPLAIN_LABEL (marker), &city_color);
+	champlain_label_set_text_color (CHAMPLAIN_LABEL (marker), &text_color);
 	champlain_location_set_location (CHAMPLAIN_LOCATION (marker), lat, lon);
 	if (g_strcmp0(name, NULL)) {
 		champlain_marker_layer_add_marker (layer, CHAMPLAIN_MARKER (marker));
@@ -387,43 +410,47 @@ listen_station(GSimpleAction *simple, GVariant *parameter, gpointer user_data) {
 
 static void
 stop_station(GSimpleAction *simple, GVariant *parameter, gpointer user_data) {
-  gnome_internet_radio_locator_player_stop(player);
-  return;
+	guint context_id;
+	gnome_internet_radio_locator_player_stop(player);
+	context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (statusbar), "Station Name");
+	gtk_statusbar_pop (GTK_STATUSBAR (statusbar), GPOINTER_TO_INT (context_id));
+	gtk_statusbar_push (GTK_STATUSBAR (statusbar), GPOINTER_TO_INT (context_id), "Search by city or drag/click on the zoomable map to listen to a radio broadcast");
+	return;
 }
 
 static void
 pause_station(GSimpleAction *simple, GVariant *parameter, gpointer user_data) {
   /* FIXME: Removing Pause.  Can't quit after gst_player_pause is called. */
 #if 0
-  gnome_internet_radio_locator_player_pause(player);
+	gnome_internet_radio_locator_player_pause(player);
 #endif
-  return;
+	return;
 }
 
 static void
 prev_station(GSimpleAction *simple, GVariant *parameter, gpointer user_data) {
 	g_print(_("Previous Internet Radio Station\n"));
-  return;
+	return;
 }
 
 static void
 stations_all(GSimpleAction *simple, GVariant *parameter, gpointer user_data) {
-  return;
+	return;
 }
 
 static void
 next_station(GSimpleAction *simple, GVariant *parameter, gpointer user_data) {
-  return;
+	return;
 }
 
 static void
 about_station_cb(GSimpleAction *simple, GVariant *parameter, gpointer user_data) {
-  return;
+	return;
 }
 
 static void
 about_program_cb(GSimpleAction *simple, GVariant *parameter, gpointer user_data) {
-  return;
+	return;
 }
 
 static void
@@ -528,7 +555,7 @@ static void
 gnome_internet_radio_locator_window_cb (GtkApplication *app,
 		gpointer user_data)
 {
-  GtkWidget *widget, *grid, *toolbar, *new, *search, *listen, *stop, *prev, *stations, *next, *station, *program, *quit;
+	GtkWidget *widget, *grid, *toolbar, *new, *search, *listen, *stop, *prev, *stations, *next, *station, *program, *quit;
 	
 	window = gtk_application_window_new (app);
 	widget = gtk_champlain_embed_new();
@@ -585,13 +612,13 @@ gnome_internet_radio_locator_window_cb (GtkApplication *app,
 	gtk_grid_attach (GTK_GRID(grid), GTK_WIDGET(toolbar), 0, 0, 1, 1);
 	gtk_grid_attach (GTK_GRID(grid), GTK_WIDGET(widget), 0, 1, 1, 1);
         champlain_view = gtk_champlain_embed_get_view (GTK_CHAMPLAIN_EMBED(widget));
-        gtk_widget_set_size_request(GTK_WIDGET(widget), 1440, 720);
+        gtk_widget_set_size_request(GTK_WIDGET(widget), 740, 580);
 	gtk_container_add (GTK_CONTAINER(window), GTK_WIDGET(grid));
 	g_signal_connect (window, "destroy", G_CALLBACK(gtk_main_quit), NULL);
 #endif
 	gtk_window_set_title (GTK_WINDOW(window), _("GNOME Internet Radio Locator"));
-	gtk_window_set_default_size (GTK_WINDOW(window), 1440, 720);
-
+	gtk_window_set_default_size (GTK_WINDOW(window), 740, 580);
+	gtk_window_maximize (GTK_WINDOW (window));
 	gnome_internet_radio_locator_app = create_gnome_internet_radio_locator_app();
 	gtk_widget_show(gnome_internet_radio_locator_app);
 
@@ -687,6 +714,7 @@ on_search_matches(GtkEntryCompletion *widget,
 	gchar *country;
 	gchar *state;
 	GError **err;
+	guint context_id;
 
 	gtk_tree_model_get_value(model, iter, STATION_LOCATION, &city);
 	gtk_tree_model_get_value(model, iter, STATION_URI, &value);
@@ -738,6 +766,16 @@ on_search_matches(GtkEntryCompletion *widget,
 	player = gst_player_new (NULL, gst_player_g_main_context_signal_dispatcher_new(NULL));
 	/* g_object_set_data(G_OBJECT(widget), "station_uri", g_value_get_string(&value)); */
 	gnome_internet_radio_locator_player_new(player, g_value_get_string(&value));
+	stationinfo = gnome_internet_radio_locator_station_load_from_file(localstation, world_station_xml_filename);
+	while (stationinfo != NULL) {
+	        if (strcasecmp(stationinfo->stream->uri, g_value_get_string(&value))==0) {
+			gchar *statusmsg = g_strconcat(stationinfo->name, " (", stationinfo->uri, ") in ", stationinfo->location, " (", stationinfo->band, ", ", g_strdup_printf("%li", stationinfo->stream->samplerate), " Hz, ", g_strdup_printf("%li", stationinfo->stream->bitrate), " kbps)", NULL);
+			context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (statusbar), "Station Name");
+			gtk_statusbar_pop (GTK_STATUSBAR (statusbar), GPOINTER_TO_INT (context_id));
+			gtk_statusbar_push (GTK_STATUSBAR (statusbar), GPOINTER_TO_INT (context_id), statusmsg);
+		}
+		stationinfo = stationinfo->next;
+	}
 	gst_player_play(player);
 	return FALSE;
 }
@@ -753,6 +791,7 @@ main (int argc,
 	GtkListStore *model;
 	GtkTreeIter iter;
 	GNOMEInternetRadioLocatorStationInfo *stationinfo, *localstation;
+	guint context_id;
 	if (gtk_clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS)
 		return 1;
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -795,7 +834,7 @@ main (int argc,
 
 	license_actor = champlain_view_get_license_actor (view);
 	champlain_license_set_extra_text (license_actor, "Free Internet Radio");
-	champlain_view_center_on (CHAMPLAIN_VIEW (view), 48.8582602, 2.29449905431968);
+	champlain_view_center_on (CHAMPLAIN_VIEW (view), 42.3617430, -71.0839082);
 	layer = create_marker_layer (view, &path);
 	champlain_view_add_layer (view, CHAMPLAIN_LAYER (path));
 	champlain_view_add_layer (view, CHAMPLAIN_LAYER (layer));
@@ -813,19 +852,10 @@ main (int argc,
 	append_point (path_layer, 45.4151, -73.1218);
 	champlain_view_add_layer (view, CHAMPLAIN_LAYER (path_layer));
 
-	gtk_widget_set_size_request (widget, 640, 481);
+	gtk_widget_set_size_request (widget, 640, 520);
 
 	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
 
-#if 0
-	button = gtk_button_new();
-	image = gtk_image_new_from_icon_name("new", GTK_ICON_SIZE_BUTTON);
-	gtk_button_set_image (GTK_BUTTON (button), image);
-	gtk_button_set_label (GTK_BUTTON (button), "New");
-	g_signal_connect(button, "clicked", G_CALLBACK(on_new_station_clicked), view);
-	gtk_container_add (GTK_CONTAINER (bbox), button);
-#endif
-
 	button = gtk_button_new();
 	image = gtk_image_new_from_icon_name("media-playback-start", GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_image (GTK_BUTTON (button), image);
@@ -978,11 +1008,15 @@ main (int argc,
 	g_signal_connect (view, "notify::state", G_CALLBACK (view_state_changed),
 			  button);
 	gtk_box_pack_end (GTK_BOX (bbox), button, FALSE, FALSE, 0);
-
 	viewport = gtk_frame_new (NULL);
 	gtk_container_add (GTK_CONTAINER (viewport), widget);
-
 	gtk_box_pack_start (GTK_BOX (vbox), bbox, FALSE, FALSE, 0);
+	statusbar = gtk_statusbar_new ();
+	context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (statusbar), "Station Name");
+	gtk_statusbar_pop (GTK_STATUSBAR (statusbar), GPOINTER_TO_INT (context_id));
+	gtk_statusbar_push (GTK_STATUSBAR (statusbar), GPOINTER_TO_INT (context_id), "Search by city or drag/click on the zoomable map to listen to a radio broadcast");
+	gtk_box_pack_end (GTK_BOX (vbox), statusbar, FALSE, FALSE, 0);
+	gtk_widget_show (statusbar);
 	gtk_container_add (GTK_CONTAINER (vbox), viewport);
 
 	/* and insert it into the main window  */
@@ -1010,4 +1044,3 @@ main (int argc,
 	return status;
 #endif
 }
-
